@@ -21,16 +21,16 @@
  */
 
 /**
- * EN-Revision: 20377
+ * EN-Revision: 22075
  */
 return array(
     // Zend_Validate_Alnum
-    "Invalid type given, value should be float, string, or integer" => "Tipo especificado inválido, o valor deve ser float, string, ou inteiro",
+    "Invalid type given, value should be float, string, or integer" => "O tipo especificado é inválido, o valor deve ser float, string, ou inteiro",
     "'%value%' contains characters which are non alphabetic and no digits" => "'%value%' contém caracteres que não são alfabéticos e nem dígitos",
     "'%value%' is an empty string" => "'%value%' é uma string vazia",
 
     // Zend_Validate_Alpha
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' contains non alphabetic characters" => "'%value%' contém caracteres não alfabéticos",
     "'%value%' is an empty string" => "'%value%' é uma string vazia",
 
@@ -38,7 +38,7 @@ return array(
     "'%value%' failed checksum validation" => "'%value%' falhou na validação do checksum",
     "'%value%' contains invalid characters" => "'%value%' contém caracteres inválidos",
     "'%value%' should have a length of %length% characters" => "'%value%' tem um comprimento de %length% caracteres",
-    "Invalid type given, value should be string" => "Tipo especificado inválido, o valor deve ser string",
+    "Invalid type given, value should be string" => "O tipo especificado é inválido, o valor deve ser string",
 
     // Zend_Validate_Between
     "'%value%' is not between '%min%' and '%max%', inclusively" => "'%value%' não está entre '%min%' e '%max%', inclusivamente",
@@ -55,14 +55,14 @@ return array(
     // Zend_Validate_CreditCard
     "Luhn algorithm (mod-10 checksum) failed on '%value%'" => "O algoritmo de Luhn (checksum de módulo 10) falhou em '%value%'",
     "'%value%' must contain only digits" => "'%value%' deve conter apenas dígitos",
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' contains an invalid amount of digits" => "'%value%' contém uma quantidade inválida de dígitos",
     "'%value%' is not from an allowed institute" => "'%value%' não vem de uma instituição autorizada",
     "Validation of '%value%' has been failed by the service" => "A validação de '%value%' falhou por causa do serviço",
     "The service returned a failure while validating '%value%'" => "O serviço devolveu um erro enquanto validava '%value%'",
 
     // Zend_Validate_Date
-    "Invalid type given, value should be string, integer, array or Zend_Date" => "Tipo especificado inválido, o valor deve ser string, inteiro, matriz ou Zend_Date",
+    "Invalid type given, value should be string, integer, array or Zend_Date" => "O tipo especificado é inválido, o valor deve ser string, inteiro, matriz ou Zend_Date",
     "'%value%' does not appear to be a valid date" => "'%value%' não parece ser uma data válida",
     "'%value%' does not fit the date format '%format%'" => "'%value%' não se encaixa no formato de data '%format%'",
 
@@ -71,12 +71,12 @@ return array(
     "A record matching %value% was found" => "Um registro foi encontrado para %value%",
 
     // Zend_Validate_Digits
-    "Invalid type given, value should be string, integer or float" => "Tipo especificado inválido, o valor deve ser string, inteiro ou float",
-    "'%value%' contains not only digit characters" => "'%value%' não contém apenas números",
+    "Invalid type given, value should be string, integer or float" => "O tipo especificado é inválido, o valor deve ser string, inteiro ou float",
+    "'%value%' contains characters which are not digits; but only digits are allowed" => "'%value%' contém caracteres que não são dígitos, mas apenas dígitos são permitidos",
     "'%value%' is an empty string" => "'%value%' é uma string vazia",
 
     // Zend_Validate_EmailAddress
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' is no valid email address in the basic format local-part@hostname" => "'%value%' não é um endereço de e-mail válido no formato local-part@hostname",
     "'%hostname%' is no valid hostname for email address '%value%'" => "'%hostname%' não é um nome de host válido para o endereço de e-mail '%value%'",
     "'%hostname%' does not appear to have a valid MX record for the email address '%value%'" => "'%hostname%' não parece ter um registro MX válido para o endereço de e-mail '%value%'",
@@ -180,18 +180,18 @@ return array(
     "File '%value%' could not be found" => "O arquivo '%value%' não pôde ser encontrado",
 
     // Zend_Validate_Float
-    "Invalid type given, value should be float, string, or integer" => "Tipo especificado inválido, o valor deve ser float, string, ou inteiro",
+    "Invalid type given, value should be float, string, or integer" => "O tipo especificado é inválido, o valor deve ser float, string, ou inteiro",
     "'%value%' does not appear to be a float" => "'%value%' não parece ser um float",
 
     // Zend_Validate_GreaterThan
     "'%value%' is not greater than '%min%'" => "'%value%' não é maior que '%min%'",
 
     // Zend_Validate_Hex
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' has not only hexadecimal digit characters" => "'%value%' não contém somente caracteres hexadecimais",
 
     // Zend_Validate_Hostname
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' appears to be an IP address, but IP addresses are not allowed" => "'%value%' parece ser um endereço de IP, mas endereços de IP não são permitidos",
     "'%value%' appears to be a DNS hostname but cannot match TLD against known list" => "'%value%' parece ser um hostname de DNS, mas o TLD não corresponde a nenhum TLD conhecido",
     "'%value%' appears to be a DNS hostname but contains a dash in an invalid position" => "'%value%' parece ser um hostname de DNS, mas contém um traço em uma posição inválida",
@@ -208,52 +208,58 @@ return array(
     "'%value%' has failed the IBAN check" => "'%value%' falhou na verificação do IBAN",
 
     // Zend_Validate_Identical
-    "The token '%token%' does not match the given token '%value%'" => "A marca '%token%' não corresponde a marca '%value%' fornecida",
-    "No token was provided to match against" => "Nenhuma marca foi fornecida para a comparação",
+    "The two given tokens do not match" => "Os dois tokens fornecidos não combinam",
+    "No token was provided to match against" => "Nenhum token foi fornecido para a comparação",
 
     // Zend_Validate_InArray
     "'%value%' was not found in the haystack" => "'%value%' não faz parte dos valores esperados",
 
     // Zend_Validate_Int
-    "Invalid type given, value should be string or integer" => "Tipo especificado inválido, o valor deve ser string ou inteiro",
+    "Invalid type given, value should be string or integer" => "O tipo especificado é inválido, o valor deve ser string ou inteiro",
     "'%value%' does not appear to be an integer" => "'%value%' não parece ser um número inteiro",
 
     // Zend_Validate_Ip
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' does not appear to be a valid IP address" => "'%value%' não parece ser um endereço de IP válido",
 
     // Zend_Validate_Isbn
+    "Invalid type given, value should be string or integer" => "O tipo especificado é inválido, o valor deve ser string ou inteiro",
     "'%value%' is no valid ISBN number" => "'%value%' não é um número ISBN válido",
 
     // Zend_Validate_LessThan
     "'%value%' is not less than '%max%'" => "'%value%' não é menor que '%max%'",
 
     // Zend_Validate_NotEmpty
-    "Invalid type given, value should be float, string, array, boolean or integer" => "Tipo especificado inválido, o valor deve ser float, string, matriz, booleano ou inteiro",
+    "Invalid type given, value should be float, string, array, boolean or integer" => "O tipo especificado é inválido, o valor deve ser float, string, matriz, booleano ou inteiro",
     "Value is required and can't be empty" => "O valor é obrigatório e não pode estar vazio",
 
     // Zend_Validate_PostCode
-    "Invalid type given, value should be string or integer" => "Tipo especificado inválido, o valor deve ser string ou inteiro",
-    "'%value%' does not appear to be an postal code" => "'%value%' não parece ser um código postal",
+    "Invalid type given. The value should be a string or a integer" => "O tipo especificado é inválido. O valor deve ser uma string ou um inteiro",
+    "'%value%' does not appear to be a postal code" => "'%value%' não parece ser um código postal",
 
     // Zend_Validate_Regex
-    "Invalid type given, value should be string, integer or float" => "Tipo especificado inválido, o valor deve ser string, inteiro ou float",
+    "Invalid type given, value should be string, integer or float" => "O tipo especificado é inválido, o valor deve ser string, inteiro ou float",
     "'%value%' does not match against pattern '%pattern%'" => "'%value%' não corresponde ao padrão '%pattern%'",
+    "There was an internal error while using the pattern '%pattern%'" => "Houve um erro interno durante o uso do padrão '%pattern%'",
 
     // Zend_Validate_Sitemap_Changefreq
     "'%value%' is no valid sitemap changefreq" => "'%value%' não é um changefreq de sitemap válido",
+    "Invalid type given, the value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
 
     // Zend_Validate_Sitemap_Lastmod
     "'%value%' is no valid sitemap lastmod" => "'%value%' não é um lastmod de sitemap válido",
+    "Invalid type given, the value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
 
     // Zend_Validate_Sitemap_Loc
     "'%value%' is no valid sitemap location" => "'%value%' não é uma localização de sitemap válida",
+    "Invalid type given, the value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
 
     // Zend_Validate_Sitemap_Priority
     "'%value%' is no valid sitemap priority" => "'%value%' não é uma prioridade de sitemap válida",
+    "Invalid type given, the value should be a integer, a float or a numeric string" => "O tipo especificado é inválido, o valor deve ser um inteiro, um float ou uma string numérica",
 
     // Zend_Validate_StringLength
-    "Invalid type given, value should be a string" => "Tipo especificado inválido, o valor deve ser uma string",
+    "Invalid type given, value should be a string" => "O tipo especificado é inválido, o valor deve ser uma string",
     "'%value%' is less than %min% characters long" => "O tamanho de '%value%' é inferior a %min% caracteres",
-    "'%value%' is more than %max% characters long" => "O tamanho de '%value%' é superior a %min% caracteres",
+    "'%value%' is more than %max% characters long" => "O tamanho de '%value%' é superior a %max% caracteres",
 );
