@@ -16,14 +16,11 @@
  * @category   Zend
  * @package    Zend
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: AllTests.php 20267 2010-01-13 20:16:35Z matthew $
  */
 
-/**
- * Test helper
- */
 require_once dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'TestHelper.php';
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -35,6 +32,7 @@ require_once 'Zend/Amf/AllTests.php';
 require_once 'Zend/Application/AllTests.php';
 require_once 'Zend/AuthTest.php';
 require_once 'Zend/Auth/AllTests.php';
+require_once 'Zend/Barcode/AllTests.php';
 require_once 'Zend/Cache/AllTests.php';
 require_once 'Zend/Captcha/AllTests.php';
 require_once 'Zend/CodeGenerator/Php/AllTests.php';
@@ -48,6 +46,7 @@ require_once 'Zend/CurrencyTest.php';
 require_once 'Zend/DateTest.php';
 require_once 'Zend/Date/AllTests.php';
 require_once 'Zend/DebugTest.php';
+require_once 'Zend/ExceptionTest.php';
 require_once 'Zend/Feed/AllTests.php';
 require_once 'Zend/File/AllTests.php';
 require_once 'Zend/FilterTest.php';
@@ -67,10 +66,12 @@ require_once 'Zend/Locale/AllTests.php';
 require_once 'Zend/Log/AllTests.php';
 require_once 'Zend/MailTest.php';
 require_once 'Zend/Mail/AllTests.php';
+require_once 'Zend/Markup/AllTests.php';
 require_once 'Zend/Measure/AllTests.php';
 require_once 'Zend/Memory/AllTests.php';
 require_once 'Zend/MimeTest.php';
 require_once 'Zend/Mime/AllTests.php';
+require_once 'Zend/Oauth/AllTests.php';
 require_once 'Zend/OpenIdTest.php';
 require_once 'Zend/OpenId/AllTests.php';
 require_once 'Zend/Paginator/AllTests.php';
@@ -79,6 +80,7 @@ require_once 'Zend/RegistryTest.php';
 require_once 'Zend/Rest/AllTests.php';
 require_once 'Zend/Queue/AllTests.php';
 require_once 'Zend/Search/Lucene/AllTests.php';
+require_once 'Zend/Serializer/AllTests.php';
 require_once 'Zend/Server/AllTests.php';
 require_once 'Zend/Service/AllTests.php';
 require_once 'Zend/Session/AllTests.php';
@@ -105,7 +107,8 @@ require_once 'Zend/XmlRpc/AllTests.php';
  * @category   Zend
  * @package    Zend
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @group      Zend
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_AllTests
@@ -165,6 +168,7 @@ class Zend_AllTests
         $suite->addTest(Zend_Application_AllTests::suite());
         $suite->addTestSuite('Zend_AuthTest');
         $suite->addTest(Zend_Auth_AllTests::suite());
+        $suite->addTest(Zend_Barcode_AllTests::suite());
         $suite->addTest(Zend_Cache_AllTests::suite());
         $suite->addTest(Zend_Captcha_AllTests::suite());
         $suite->addTest(Zend_CodeGenerator_Php_AllTests::suite());
@@ -178,6 +182,7 @@ class Zend_AllTests
         $suite->addTest(Zend_Db_AllTests::suite());
         $suite->addTestSuite('Zend_DebugTest');
         $suite->addTest(Zend_Dom_AllTests::suite());
+        $suite->addTestSuite('Zend_ExceptionTest');
         $suite->addTest(Zend_Feed_AllTests::suite());
         $suite->addTest(Zend_File_AllTests::suite());
         $suite->addTestSuite('Zend_FilterTest');
@@ -196,15 +201,19 @@ class Zend_AllTests
         $suite->addTest(Zend_Locale_AllTests::suite());
         $suite->addTest(Zend_Log_AllTests::suite());
         $suite->addTestSuite('Zend_MailTest');
+        $suite->addTest(Zend_Mail_AllTests::suite());
+        $suite->addTest(Zend_Markup_AllTests::suite());
         $suite->addTest(Zend_Measure_AllTests::suite());
         $suite->addTestSuite('Zend_MimeTest');
         $suite->addTest(Zend_Mime_AllTests::suite());
+        $suite->addTest(Zend_Oauth_AllTests::suite());
         $suite->addTest(Zend_Paginator_AllTests::suite());
         $suite->addTest(Zend_Pdf_AllTests::suite());
         $suite->addTestSuite('Zend_RegistryTest');
         $suite->addTest(Zend_Rest_AllTests::suite());
         $suite->addTest(Zend_Queue_AllTests::suite());
         $suite->addTest(Zend_Search_Lucene_AllTests::suite());
+        $suite->addTest(Zend_Serializer_AllTests::suite());
         $suite->addTest(Zend_Server_AllTests::suite());
         $suite->addTest(Zend_Service_AllTests::suite());
         $suite->addTest(Zend_Tag_AllTests::suite());
