@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: CoreTest.php 21292 2010-03-02 10:25:22Z mabe $
+ * @version    $Id: CoreTest.php 22652 2010-07-21 04:30:24Z ramon $
  */
 
 /**
@@ -86,7 +86,7 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase
         $test->setConfig($config);
         $this->assertEquals(3600, $test->getOption('lifetime'));
     }
-    
+
     /**
      * @group ZF-9092
      */
@@ -522,4 +522,18 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase
         $this->assertContains('id6', $ids);
     }
 
+    /**
+     * @group ZF-10189
+     */
+    public function testIfFileZendLogWasIncluded()
+    {
+        if (class_exists('Zend_Log', false)) {
+            $this->markTestSkipped('File Zend/Log.php already included');
+        }
+
+        $cacheCore = new Zend_Cache_Core(
+            array('logging' => true)
+        );
+        $this->assertTrue($cacheCore->getOption('logger') instanceof Zend_Log);
+    }
 }
