@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RewriteTest.php 20246 2010-01-12 21:36:08Z dasprid $
+ * @version    $Id: RewriteTest.php 22417 2010-06-11 14:15:05Z rob $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -732,6 +732,37 @@ class Zend_Controller_Router_RewriteTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals('/articles/777', $url);
     }
+    
+
+    /**
+     * Test that it is possible to generate a URL with a numerical key
+     *
+     * @since  2010-06-11
+     * @group  ZF-8914
+     * @covers Zend_Controller_Router_Rewrite::assemble
+     */
+    public function testCanGenerateNumericKeyUri()
+    {
+        $this->_router->addRoute(
+            'default', 
+            new Zend_Controller_Router_Route(
+                ':controller/:action/*',
+                array('controller' => 'index', 'action' => 'index')
+            )
+       );
+
+       $params = array(
+            'controller' => 'index',
+            'action'     => 'index',
+            '2'          => 'foo',
+            'page'       => 'bar',
+        );
+
+        $this->assertEquals(
+            '/index/index/2/foo/page/bar',
+            $this->_router->assemble($params)
+        );
+    }
 }
 
 
