@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DiffieHellmanTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: DiffieHellmanTest.php 22053 2010-04-29 14:29:52Z padraic $
  */
 
 require_once 'Zend/Crypt/DiffieHellman.php';
@@ -133,4 +133,12 @@ class Zend_Crypt_DiffieHellmanTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($expectedSharedSecret, $aliceSecretKey);
         $this->assertEquals($expectedSharedSecret, $bobSecretKey);
     }
+
+    public function testGenerateKeysWithUnsetPrivateKey()
+    {
+        $dh = new Zend_Crypt_DiffieHellman(563, 5);
+        $dh->generateKeys();
+        $privateKey = $dh->getPrivateKey();
+        $this->assertNotNull($privateKey);
+    }
 }
