@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RsaTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: RsaTest.php 22042 2010-04-28 19:33:31Z padraic $
  */
 
 require_once 'Zend/Crypt/Rsa.php';
@@ -315,4 +315,13 @@ CERT;
         }
     }
 
+    /**
+     * @group ZF-8846
+     */
+    public function testLoadsPublicKeyFromPEMWithoutPrivateKeyAndThrowsNoException()
+    {
+        $rsa = new Zend_Crypt_Rsa;
+        $rsa->setPemString($this->_testPemStringPublic);
+    }
+
 }
