@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 21092 2010-02-19 18:41:54Z mikaelkael $
+ * @version    $Id: TestCommon.php 22230 2010-05-21 20:59:18Z ralph $
  */
 
 
@@ -875,7 +875,27 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         }
     }
 
+    /**
+     * @group ZF-9836
+     */
+    public function testTableRowIsIterable()
+    {
+        $table = $this->_table['bugs'];
 
+        $rowset = $table->find(1);
+        $row = $rowset->current();
+        $this->assertTrue($row instanceof Traversable);
+        $this->assertTrue($row instanceof IteratorAggregate);
+        $this->assertType('ArrayIterator', $row->getIterator());
+        
+        $count=0;
+        foreach ($row as $columnValue) {
+            $count++;
+        }
+        
+        $this->assertEquals(8, $count, 'The row was iterated, there should be 8 columns iterated');
+    }
+    
 
     /**
      * Utility methods below
