@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AtomTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: AtomTest.php 22108 2010-05-05 13:44:11Z padraic $
  */
 
 require_once 'PHPUnit/Framework/TestCase.php';
@@ -222,6 +222,17 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($edate->equals($feed->getDateModified()));
     }
 
+    /**
+     * Get Last Build Date (Unencoded Text)
+     */
+    public function testGetsLastBuildDateAlwaysReturnsNullForAtom()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/datemodified/plain/atom10.xml')
+        );
+        $this->assertNull($feed->getLastBuildDate());
+    }
+
     /**
      * Get Generator (Unencoded Text)
      */
@@ -390,6 +401,15 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('http://www.example.com/feed/atom', $feed->getFeedLink());
     }
 
+    public function testGetsOriginalSourceUriIfFeedLinkNotAvailableFromFeed()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/feedlink/plain/atom10_NoFeedLink.xml')
+        );
+        $feed->setOriginalSourceUri('http://www.example.com/feed/atom');
+        $this->assertEquals('http://www.example.com/feed/atom', $feed->getFeedLink());
+    }
+
     /**
      * Get Pubsubhubbub Hubs
      */
@@ -491,4 +511,42 @@ class Zend_Feed_Reader_Feed_AtomTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(array(), (array) $feed->getCategories());
         $this->assertEquals(array(), array_values($feed->getCategories()->getValues()));
     }
+
+    /**
+     * Get Image (Unencoded Text)
+     */
+    public function testGetsImageFromAtom03()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/image/plain/atom03.xml')
+        );
+        $this->assertEquals(array('uri'=>'http://www.example.com/logo.gif'), $feed->getImage());
+    }
+
+    public function testGetsImageFromAtom10()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/image/plain/atom10.xml')
+        );
+        $this->assertEquals(array('uri'=>'http://www.example.com/logo.gif'), $feed->getImage());
+    }
+
+    /**
+     * Get Image (Unencoded Text) When Missing
+     */
+    public function testGetsImageFromAtom03_None()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/image/plain/none/atom03.xml')
+        );
+        $this->assertEquals(null, $feed->getImage());
+    }
+
+    public function testGetsImageFromAtom10_None()
+    {
+        $feed = Zend_Feed_Reader::importString(
+            file_get_contents($this->_feedSamplePath.'/image/plain/none/atom10.xml')
+        );
+        $this->assertEquals(null, $feed->getImage());
+    }
 }
