@@ -185,18 +185,6 @@ class Zend_Feed_Writer_EntryTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($expected, $entry->getEnclosure());
     }
     
-    /**
-     * @expectedException Zend_Feed_Exception
-     */
-    public function testAddsEnclosureThrowsExceptionOnMissingType()
-    {
-        $entry = new Zend_Feed_Writer_Entry;
-        $entry->setEnclosure(array(
-            'uri' => 'http://example.com/audio.mp3',
-            'length' => '1337'
-        ));
-    }
-    
     /**
      * @expectedException Zend_Feed_Exception
      */
@@ -209,44 +197,6 @@ class Zend_Feed_Writer_EntryTest extends PHPUnit_Framework_TestCase
         ));
     }
     
-    /**
-     * @expectedException Zend_Feed_Exception
-     */
-    public function testAddsEnclosureThrowsExceptionOnMissingLength()
-    {
-        $entry = new Zend_Feed_Writer_Entry;
-        $entry->setEnclosure(array(
-            'type' => 'audio/mpeg',
-            'uri' => 'http://example.com/audio.mp3'
-        ));
-    }
-    
-    /**
-     * @expectedException Zend_Feed_Exception
-     */
-    public function testAddsEnclosureThrowsExceptionOnNonNumericLength()
-    {
-        $entry = new Zend_Feed_Writer_Entry;
-        $entry->setEnclosure(array(
-            'type' => 'audio/mpeg',
-            'uri' => 'http://example.com/audio.mp3',
-            'length' => 'abc'
-        ));
-    }
-    
-    /**
-     * @expectedException Zend_Feed_Exception
-     */
-    public function testAddsEnclosureThrowsExceptionOnNegativeLength()
-    {
-        $entry = new Zend_Feed_Writer_Entry;
-        $entry->setEnclosure(array(
-            'type' => 'audio/mpeg',
-            'uri' => 'http://example.com/audio.mp3',
-            'length' => -23
-        ));
-    }
-    
     /**
      * @expectedException Zend_Feed_Exception
      */
