@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: AllTests.php 22232 2010-05-21 22:04:05Z alab $
  */
 
 require_once dirname(dirname(dirname(dirname(__FILE__)))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
@@ -32,6 +32,7 @@ require_once 'Zend/Form/Decorator/DescriptionTest.php';
 require_once 'Zend/Form/Decorator/ErrorsTest.php';
 require_once 'Zend/Form/Decorator/FieldsetTest.php';
 require_once 'Zend/Form/Decorator/FileTest.php';
+require_once 'Zend/Form/Decorator/FormErrorsTest.php';
 require_once 'Zend/Form/Decorator/FormTest.php';
 require_once 'Zend/Form/Decorator/HtmlTagTest.php';
 require_once 'Zend/Form/Decorator/ImageTest.php';
@@ -64,6 +65,7 @@ class Zend_Form_Decorator_AllTests
         $suite->addTestSuite('Zend_Form_Decorator_ErrorsTest');
         $suite->addTestSuite('Zend_Form_Decorator_FieldsetTest');
         $suite->addTestSuite('Zend_Form_Decorator_FileTest');
+        $suite->addTestSuite('Zend_Form_Decorator_FormErrorsTest');
         $suite->addTestSuite('Zend_Form_Decorator_FormTest');
         $suite->addTestSuite('Zend_Form_Decorator_HtmlTagTest');
         $suite->addTestSuite('Zend_Form_Decorator_ImageTest');
