@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ImageTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ImageTest.php 22329 2010-05-30 15:12:58Z bittarman $
  */
 
 // Call Zend_Form_Element_ImageTest::main() if this source file is executed directly.
@@ -205,6 +205,17 @@ class Zend_Form_Element_ImageTest extends PHPUnit_Framework_TestCase
             $this->markTestIncomplete('Error occurs for PHP 5.1.4 on Windows');
         }
     }
+
+    /**
+     * Prove the fluent interface on Zend_Form_Element_Image::loadDefaultDecorators
+     *
+     * @link http://framework.zend.com/issues/browse/ZF-9913
+     * @return void
+     */
+    public function testFluentInterfaceOnLoadDefaultDecorators()
+    {
+        $this->assertSame($this->element, $this->element->loadDefaultDecorators());
+    }
 }
 
 // Call Zend_Form_Element_ImageTest::main() if this source file is executed directly.
