@@ -135,12 +135,22 @@ require_once 'Zend/Gdata/Gapps/EmailListRecipientFeedTest.php';
 require_once 'Zend/Gdata/Gapps/EmailListRecipientQueryTest.php';
 require_once 'Zend/Gdata/Gapps/EmailListTest.php';
 require_once 'Zend/Gdata/Gapps/ErrorTest.php';
+require_once 'Zend/Gdata/Gapps/GroupEntryTest.php';
+require_once 'Zend/Gdata/Gapps/GroupFeedTest.php';
+require_once 'Zend/Gdata/Gapps/GroupQueryTest.php';
 require_once 'Zend/Gdata/Gapps/LoginTest.php';
+require_once 'Zend/Gdata/Gapps/MemberEntryTest.php';
+require_once 'Zend/Gdata/Gapps/MemberFeedTest.php';
+require_once 'Zend/Gdata/Gapps/MemberQueryTest.php';
 require_once 'Zend/Gdata/Gapps/NameTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameEntryTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameFeedTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameQueryTest.php';
 require_once 'Zend/Gdata/Gapps/NicknameTest.php';
+require_once 'Zend/Gdata/Gapps/OwnerEntryTest.php';
+require_once 'Zend/Gdata/Gapps/OwnerFeedTest.php';
+require_once 'Zend/Gdata/Gapps/OwnerQueryTest.php';
+require_once 'Zend/Gdata/Gapps/PropertyTest.php';
 require_once 'Zend/Gdata/Gapps/QuotaTest.php';
 require_once 'Zend/Gdata/Gapps/ServiceExceptionTest.php';
 require_once 'Zend/Gdata/Gapps/UserEntryTest.php';
@@ -319,12 +329,22 @@ class Zend_Gdata_AllTests
         $suite->addTestSuite('Zend_Gdata_Gapps_EmailListRecipientQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_EmailListTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_ErrorTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_GroupEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_GroupFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_GroupQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_LoginTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_MemberEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_MemberFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_MemberQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NameTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameEntryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameFeedTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameQueryTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_NicknameTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_OwnerEntryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_OwnerFeedTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_OwnerQueryTest');
+        $suite->addTestSuite('Zend_Gdata_Gapps_PropertyTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_QuotaTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_ServiceExceptionTest');
         $suite->addTestSuite('Zend_Gdata_Gapps_UserEntryTest');
