@@ -15,11 +15,16 @@
  * @category   Zend
  * @package    Zend_Gdata
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
 
+/**
+ * Test helper
+ */
+require_once dirname(__FILE__) . '/../../TestHelper.php';
+
 require_once 'Zend/Gdata/AuthSub.php';
 require_once 'Zend/Gdata/HttpClient.php';
 
@@ -27,7 +32,7 @@ require_once 'Zend/Gdata/HttpClient.php';
  * @category   Zend
  * @package    Zend_Gdata
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Gdata
  */
@@ -113,4 +118,16 @@ class Zend_Gdata_AuthSubTest extends PHPUnit_Framework_TestCase
                                 'Auth header not found for sig verification.');
         }
     }
+
+    public function testPrivateKeyNotFound()
+    {
+        $this->setExpectedException('Zend_Gdata_App_InvalidArgumentException');
+
+        if (!extension_loaded('openssl')) {
+            $this->markTestSkipped('The openssl extension is not available');
+        } else {
+            $c = new Zend_Gdata_HttpClient();
+            $c->setAuthSubPrivateKeyFile("zendauthsubfilenotfound",  null, true);
+        }
+    }
 }
