@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StaticTest.php 21020 2010-02-11 17:27:23Z shahar $
+ * @version    $Id: StaticTest.php 21920 2010-04-16 22:10:02Z dragonbe $
  */
 
 require_once realpath(dirname(__FILE__) . '/../../../') . '/TestHelper.php';
@@ -542,6 +542,49 @@ class Zend_Http_Client_StaticTest extends PHPUnit_Framework_TestCase
         // if the bug exists this call should creates a fatal error
         $client->setAuth(false);
     }
+    
+	/**
+     * Testing if the connection isn't closed
+     * 
+     * @group ZF-9685
+     */
+    public function testOpenTempStreamWithValidFileDoesntThrowsException()
+    {
+    	$url = 'http://www.example.com';
+    	$config = array (
+			'output_stream' => realpath(dirname(__FILE__) . '/_files/zend_http_client_stream.file'),
+		);
+		$client = new Zend_Http_Client($url, $config);
+		try {
+			$result = $client->request();
+		} catch (Zend_Http_Client_Exception $e) {
+			$this->fail('Unexpected exception was thrown');
+		}
+		// we can safely return until we can verify link is still active
+		// @todo verify link is still active
+		return;
+    }
+    
+    /**
+     * Testing if the connection can be closed
+     * 
+     * @group ZF-9685
+     */
+    public function testOpenTempStreamWithBogusFileClosesTheConnection()
+    {
+    	$url = 'http://www.example.com';
+    	$config = array (
+			'output_stream' => '/path/to/bogus/file.ext',
+		);
+		$client = new Zend_Http_Client($url, $config);
+		try {
+			$result = $client->request();
+			$this->fail('Expected exception was not thrown');
+		} catch (Zend_Http_Client_Exception $e) {
+			// we return since we expect the exception
+			return;
+		}
+    }
 
     /**
      * Data providers
