@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ResponseTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ResponseTest.php 22811 2010-08-08 10:33:21Z shahar $
  */
 
 /**
@@ -162,6 +162,20 @@ class Zend_Http_ResponseTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($response->isRedirect(), 'Response is an error, but isRedirect() returned true');
     }
 
+    /**
+     * @group ZF-5520
+     */
+    public function test302LocationHeaderMatches()
+    {
+        $headerName  = 'Location';
+        $headerValue = 'http://www.google.com/ig?hl=en';
+        $response    = Zend_Http_Response::fromString($this->readResponse('response_302'));
+        $responseIis = Zend_Http_Response::fromString($this->readResponse('response_302_iis'));
+
+        $this->assertEquals($headerValue, $response->getHeader($headerName));
+        $this->assertEquals($headerValue, $responseIis->getHeader($headerName));
+    }
+
     public function test300isRedirect()
     {
         $response = Zend_Http_Response::fromString($this->readResponse('response_302'));
@@ -321,7 +335,58 @@ class Zend_Http_ResponseTest extends PHPUnit_Framework_TestCase
         $response = Zend_Http_Response::fromString($this->readResponse('response_multibyte_body'));
         $this->assertEquals($md5, md5($response->getBody()));
     }
-
+    
+    /**
+     * Test that headers are properly set when passed to the constructor as an associative array
+     * 
+     * @group ZF-10277
+     */
+    public function testConstructorWithHeadersAssocArray()
+    {
+        $response = new Zend_Http_Response(200, array(
+            'content-type' => 'text/plain',
+            'x-foo'        => 'bar:baz'
+        ));
+        
+        $this->assertEquals('text/plain', $response->getHeader('content-type'));
+        $this->assertEquals('bar:baz', $response->getHeader('x-foo'));
+    }
+    
+    /**
+     * Test that headers are properly parsed when passed to the constructor as an indexed array
+     *
+     * @link  http://framework.zend.com/issues/browse/ZF-10277
+     * @group ZF-10277
+     */
+    public function testConstructorWithHeadersIndexedArrayZF10277()
+    {
+        $response = new Zend_Http_Response(200, array(
+            'content-type: text/plain',
+            'x-foo: bar:baz'
+        ));
+        
+        $this->assertEquals('text/plain', $response->getHeader('content-type'));
+        $this->assertEquals('bar:baz', $response->getHeader('x-foo'));
+    }
+    
+    /**
+     * Test that headers are properly parsed when passed to the constructor as 
+     * an indexed array with no whitespace after the ':' sign
+     *
+     * @link  http://framework.zend.com/issues/browse/ZF-10277
+     * @group ZF-10277
+     */
+    public function testConstructorWithHeadersIndexedArrayNoWhitespace()
+    {
+        $response = new Zend_Http_Response(200, array(
+            'content-type:text/plain',
+            'x-foo:bar:baz'
+        ));
+        
+        $this->assertEquals('text/plain', $response->getHeader('content-type'));
+        $this->assertEquals('bar:baz', $response->getHeader('x-foo'));
+    }
+    
     /**
      * Helper function: read test response from file
      *
