@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AttributeTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: AttributeTest.php 22162 2010-05-14 10:15:55Z sgehrig $
  */
 
 /**
@@ -307,7 +307,7 @@ class Zend_Ldap_AttributeTest extends PHPUnit_Framework_TestCase
     {
         $data=array('ts' => array('dummy'));
         $retTs=Zend_Ldap_Attribute::getDateTimeAttribute($data, 'ts', 0);
-        $this->assertNull($retTs);
+        $this->assertEquals('dummy', $retTs);
     }
 
     public function testGetDateTimeValueNegativeOffet()
@@ -418,6 +418,13 @@ class Zend_Ldap_AttributeTest extends PHPUnit_Framework_TestCase
             Zend_Ldap_Attribute::convertFromLdapDateTimeValue($ldap));
     }
 
+    public function testConvertFromLdapDateTimeValueActiveDirectory()
+    {
+        $ldap='20080625123030.0+0200';
+        $this->assertEquals(gmmktime(10, 30, 30, 6, 25, 2008),
+            Zend_Ldap_Attribute::convertFromLdapDateTimeValue($ldap));
+    }
+
     public function testConvertToLdapDateTimeValue()
     {
         $ts=mktime(12, 30, 30, 6, 25, 2008);
