@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: LoaderTest.php 20990 2010-02-08 18:20:39Z matthew $
+ * @version    $Id: LoaderTest.php 22020 2010-04-27 16:35:56Z matthew $
  */
 
 // Call Zend_LoaderTest::main() if this source file is executed directly.
@@ -535,6 +535,20 @@ class Zend_LoaderTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(Zend_Loader::isReadable($path));
     }
 
+    /**
+     * @group ZF-9263
+     * @group ZF-9166
+     * @group ZF-9306
+     */
+    public function testIsReadableShouldFailEarlyWhenProvidedInvalidWindowsAbsolutePath()
+    {
+        if (strtoupper(substr(PHP_OS, 0, 3)) != 'WIN') {
+            $this->markTestSkipped('Windows-only test');
+        }
+        $path = 'C:/this/file/should/not/exist.php';
+        $this->assertFalse(Zend_Loader::isReadable($path));
+    }
+
     /**
      * In order to play nice with spl_autoload, an autoload callback should
      * *not* emit errors (exceptions are okay). ZF-2923 requests that this
