@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OnlineTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: OnlineTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 /**
@@ -29,7 +29,7 @@ require_once dirname(__FILE__) . '/../../../TestHelper.php';
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Service
  * @group      Zend_Service_Flickr
@@ -87,7 +87,7 @@ class Zend_Service_Flickr_OnlineTest extends PHPUnit_Framework_TestCase
 
         $resultSet = $this->_flickr->groupPoolGetPhotos('20083316@N00', $options);
 
-        $this->assertEquals(21770, $resultSet->totalResultsAvailable);
+        $this->assertGreaterThan(20000, $resultSet->totalResultsAvailable);
         $this->assertEquals(10, $resultSet->totalResults());
         $this->assertEquals(10, $resultSet->totalResultsReturned);
         $this->assertEquals(1, $resultSet->firstResultPosition);
@@ -209,13 +209,21 @@ class Zend_Service_Flickr_OnlineTest extends PHPUnit_Framework_TestCase
             $dateTakenPrevious = $result->datetaken;
         }
     }
+
+    /**
+     *  @see ZF-6397
+     */
+    function testTotalForEmptyResultSet()
+    {
+        $this->assertEquals(0, $this->_flickr->tagSearch('zendflickrtesttagnoresults')->totalResults());
+    }
 }
 
 /**
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Service
  * @group      Zend_Service_Flickr
