@@ -15,66 +15,62 @@
  * @category   Zend
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
- * @version    $Id: BlobStorageTest.php 14561 2009-05-07 08:05:12Z unknown $
+ * @version    $Id$
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
+
 /**
  * Test helpers
  */
 require_once dirname(__FILE__) . '/../../../TestHelper.php';
 
-/**
- * @see Zend_Service_WindowsAzure_Storage_Table 
- */
+/** Zend_Service_WindowsAzure_Storage_Table */
 require_once 'Zend/Service/WindowsAzure/Storage/Table.php';
 
-if (!defined('PHPUnit_MAIN_METHOD')) {
-    define('PHPUnit_MAIN_METHOD', 'Zend_Service_WindowsAzure_TableStorageTest::main');
-}
-
 /**
  * @category   Zend
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
- * @version    $Id: BlobStorageTest.php 14561 2009-05-07 08:05:12Z unknown $
+ * @version    $Id$
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestCase
 {
+    
+    protected static $uniqId = 0;
+    
     public function __construct()
     {
     }
-
-    public static function main()
-    {
-        $suite  = new PHPUnit_Framework_TestSuite("Zend_Service_WindowsAzure_TableStorageTest");
-        $result = PHPUnit_TextUI_TestRunner::run($suite);
-    }
-
+    
     /**
      * Test setup
      */
     protected function setUp()
     {
         if (!TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_RUNTESTS) {
-            $this->markTestSkipped('Windows Azure Tests disabled');
+            $this->markTestSkipped('This test case requires TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_RUNTESTS to be enabled.');
         }
     }
-
+    
     /**
      * Test teardown
      */
     protected function tearDown()
     {
+        if ($this->status == PHPUnit_Runner_BaseTestRunner::STATUS_SKIPPED) {
+            return;
+        }
         $storageClient = $this->createStorageInstance();
-        for ($i = 1; $i <= self::$uniqId; $i++) {
+        for ($i = 1; $i <= self::$uniqId; $i++)
+        {
             try { $storageClient->deleteTable(TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_TABLENAME_PREFIX . $i); } catch (Exception $e) { }
         }
     }
-
+    
     protected function createStorageInstance()
     {
         $storageClient = null;
@@ -83,22 +79,20 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         } else {
             $storageClient = new Zend_Service_WindowsAzure_Storage_Table(TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_HOST_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_ACCOUNT_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_KEY_DEV, true, Zend_Service_WindowsAzure_RetryPolicy_RetryPolicyAbstract::retryN(10, 250));
         }
-
+        
         if (TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY) {
             $storageClient->setProxy(TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_PORT, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_CREDENTIALS);
         }
 
         return $storageClient;
     }
-
-    protected static $uniqId = 0;
-
+    
     protected function generateName()
     {
         self::$uniqId++;
         return TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_TABLENAME_PREFIX . self::$uniqId;
     }
-
+    
     /**
      * Test create table
      */
@@ -106,15 +100,15 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
     {
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
-
+        
         $result = $storageClient->createTable($tableName);
         $this->assertEquals($tableName, $result->Name);
-
+        
         $result = $storageClient->listTables();
         $this->assertEquals(1, count($result));
         $this->assertEquals($tableName, $result[0]->Name);
     }
-
+    
     /**
      * Test table exists
      */
@@ -123,17 +117,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName1 = $this->generateName();
         $tableName2 = $this->generateName();
         $storageClient = $this->createStorageInstance();
-
+        
         $storageClient->createTable($tableName1);
         $storageClient->createTable($tableName2);
 
         $result = $storageClient->tableExists($tableName2);
         $this->assertTrue($result);
-
+        
         $result = $storageClient->tableExists(md5(time()));
         $this->assertFalse($result);
     }
-
+    
     /**
      * Test list tables
      */
@@ -142,7 +136,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName1 = $this->generateName();
         $tableName2 = $this->generateName();
         $storageClient = $this->createStorageInstance();
-
+        
         $storageClient->createTable($tableName1);
         $storageClient->createTable($tableName2);
 
@@ -151,7 +145,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $this->assertEquals($tableName1, $result[0]->Name);
         $this->assertEquals($tableName2, $result[1]->Name);
     }
-
+    
     /**
      * Test delete table
      */
@@ -159,14 +153,14 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
     {
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
-
+        
         $storageClient->createTable($tableName);
         $storageClient->deleteTable($tableName);
-
+        
         $result = $storageClient->listTables();
         $this->assertEquals(0, count($result));
     }
-
+    
     /**
      * Test insert entity
      */
@@ -175,17 +169,37 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $result = $storageClient->insertEntity($tableName, $entity);
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
         $this->assertNotEquals('', $result->getEtag());
         $this->assertEquals($entity, $result);
     }
+    
+    /**
+     * Test insert entity, with XML in content. This should not break the XML sent to Windows Azure.
+     */
+    public function testInsertEntity_Security_HtmlSpecialChars()
+    {
+        $tableName = $this->generateName();
+        $storageClient = $this->createStorageInstance();
+        $storageClient->createTable($tableName);
+        
+        $entities = $this->_generateEntities(1);
+        $entity = $entities[0];
+        $entity->FullName = 'XML <test>'; // this should work without breaking the XML
+        
+        $result = $storageClient->insertEntity($tableName, $entity);
 
+        $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
+        $this->assertNotEquals('', $result->getEtag());
+        $this->assertEquals($entity, $result);
+    }
+    
     /**
      * Test delete entity, not taking etag into account
      */
@@ -194,16 +208,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
+        
         $result = $storageClient->insertEntity($tableName, $entity);
-
+        
         $this->assertEquals($entity, $result);
-
+        
         $storageClient->deleteEntity($tableName, $entity);
     }
-
+    
     /**
      * Test delete entity, taking etag into account
      */
@@ -212,17 +227,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $result = $storageClient->insertEntity($tableName, $entity);
 
         $this->assertEquals($entity, $result);
 
         // Set "old" etag
         $entity->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
-
+        
         $exceptionThrown = false;
         try {
             $storageClient->deleteEntity($tableName, $entity, true);
@@ -231,7 +246,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-
+    
     /**
      * Test retrieve entity by id
      */
@@ -240,16 +255,16 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $storageClient->insertEntity($tableName, $entity);
-
+        
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey(), 'TSTest_TestEntity');
         $this->assertEquals($entity, $result);
     }
-
+    
     /**
      * Test retrieve entity by id (> 256 key characters)
      */
@@ -258,18 +273,18 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
         $entity->setPartitionKey(str_repeat('a', 200));
         $entity->setRowKey(str_repeat('a', 200));
-
+        
         $storageClient->insertEntity($tableName, $entity);
-
+        
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey(), 'TSTest_TestEntity');
         $this->assertEquals($entity, $result);
     }
-
+    
     /**
      * Test retrieve entity by id, DynamicTableEntity
      */
@@ -278,17 +293,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $storageClient->insertEntity($tableName, $entity);
-
+        
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey());
         $this->assertEquals($entity->FullName, $result->Name);
         $this->assertType('Zend_Service_WindowsAzure_Storage_DynamicTableEntity', $result);
     }
-
+    
     /**
      * Test update entity, not taking etag into account
      */
@@ -297,13 +312,13 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $storageClient->insertEntity($tableName, $entity);
         $entity->Age = 0;
-
+        
         $result = $storageClient->updateEntity($tableName, $entity);
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
@@ -311,7 +326,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $this->assertEquals(0, $result->Age);
         $this->assertEquals($entity, $result);
     }
-
+    
     /**
      * Test update entity, taking etag into account
      */
@@ -320,16 +335,16 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $storageClient->insertEntity($tableName, $entity);
         $entity->Age = 0;
-
+        
         // Set "old" etag
         $entity->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
-
+        
         $exceptionThrown = false;
         try {
             $storageClient->updateEntity($tableName, $entity, true);
@@ -338,7 +353,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-
+    
     /**
      * Test merge entity, not taking etag into account
      */
@@ -347,19 +362,19 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $storageClient->insertEntity($tableName, $entity);
-
+        
         $dynamicEntity = new Zend_Service_WindowsAzure_Storage_DynamicTableEntity($entity->getPartitionKey(), $entity->getRowKey());
         $dynamicEntity->Myproperty = 10;
         $dynamicEntity->Otherproperty = "Test";
         $dynamicEntity->Age = 0;
-
+        
         $storageClient->mergeEntity($tableName, $dynamicEntity, false, array('Myproperty', 'Otherproperty')); // only update 'Myproperty' and 'Otherproperty'
-
+        
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey());
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
@@ -369,7 +384,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $this->assertEquals($dynamicEntity->Myproperty, $result->Myproperty);
         $this->assertEquals($dynamicEntity->Otherproperty, $result->Otherproperty);
     }
-
+    
     /**
      * Test merge entity, taking etag into account
      */
@@ -378,20 +393,20 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-
+        
         $storageClient->insertEntity($tableName, $entity);
-
+        
         $dynamicEntity = new Zend_Service_WindowsAzure_Storage_DynamicTableEntity($entity->getPartitionKey(), $entity->getRowKey());
         $dynamicEntity->Myproperty = 10;
         $dynamicEntity->Otherproperty = "Test";
         $dynamicEntity->Age = 0;
-
+        
         // Set "old" etag
         $entity->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
-
+        
         $exceptionThrown = false;
         try {
             $storageClient->mergeEntity($tableName, $dynamicEntity, true);
@@ -400,7 +415,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-
+    
     /**
      * Test retrieve entities, all
      */
@@ -409,16 +424,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(20);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         $result = $storageClient->retrieveEntities($tableName, 'TSTest_TestEntity');
         $this->assertEquals(20, count($result));
     }
-
+    
     /**
      * Test retrieve entities, all, DynamicTableEntity
      */
@@ -427,20 +443,22 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(20);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(20, count($result));
-
-        foreach ($result as $item) {
+        
+        foreach ($result as $item)
+        {
             $this->assertType('Zend_Service_WindowsAzure_Storage_DynamicTableEntity', $item);
         }
     }
-
+    
     /**
      * Test retrieve entities, filtered
      */
@@ -449,16 +467,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(5);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         $result = $storageClient->retrieveEntities($tableName, 'PartitionKey eq \'' . $entities[0]->getPartitionKey() . '\' and RowKey eq \'' . $entities[0]->getRowKey() . '\'', 'TSTest_TestEntity');
         $this->assertEquals(1, count($result));
     }
-
+    
     /**
      * Test retrieve entities, fluent interface
      */
@@ -467,12 +486,13 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(10);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         $result = $storageClient->retrieveEntities(
             $storageClient->select()
                           ->from($tableName)
@@ -480,11 +500,11 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
                           ->andWhere('RowKey eq ?', $entities[0]->getRowKey()),
             'TSTest_TestEntity'
         );
-
+        
         $this->assertEquals(1, count($result));
         $this->assertEquals($entities[0], $result[0]);
     }
-
+    
     /**
      * Test retrieve entities, fluent interface
      */
@@ -493,12 +513,13 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(10);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         $result = $storageClient->retrieveEntities(
             $storageClient->select()
                           ->from($tableName)
@@ -506,11 +527,11 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
                           ->andWhere('PartitionKey eq ?', $entities[0]->getPartitionKey()),
             'TSTest_TestEntity'
         );
-
+        
         $this->assertEquals(1, count($result));
         $this->assertEquals($entities[0], $result[0]);
     }
-
+    
     /**
      * Test retrieve entities, fluent interface, top specification
      */
@@ -519,21 +540,22 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(10);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         $result = $storageClient->retrieveEntities(
             $storageClient->select()->top(4)
                           ->from($tableName),
             'TSTest_TestEntity'
         );
-
+        
         $this->assertEquals(4, count($result));
     }
-
+    
     /**
      * Test batch commit, success
      */
@@ -542,38 +564,41 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(20);
         $entities1 = array_slice($entities, 0, 10);
         $entities2 = array_slice($entities, 10, 10);
-
+        
         // Insert entities
-        foreach ($entities1 as $entity) {
+        foreach ($entities1 as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-
+        
         // Insert entities in batch
-        foreach ($entities2 as $entity) {
+        foreach ($entities2 as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         // Delete entities
-        foreach ($entities1 as $entity) {
+        foreach ($entities1 as $entity)
+        {
             $storageClient->deleteEntity($tableName, $entity);
         }
-
+        
         // Commit
         $batch->commit();
-
+        
         // Verify
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(10, count($result));
     }
-
+    
     /**
      * Test batch rollback, success
      */
@@ -582,26 +607,27 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(10);
-
+        
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-
+        
         // Insert entities in batch
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         // Rollback
         $batch->rollback();
-
+        
         // Verify
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(0, count($result));
     }
-
+    
     /**
      * Test batch commit, fail updates
      */
@@ -610,28 +636,29 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(10);
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         // Make some entity updates with "old" etags
         $entities[0]->Age = 0;
         $entities[0]->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
         $entities[1]->Age = 0;
         $entities[1]->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
         $entities[2]->Age = 0;
-
+        
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-
+        
         // Update entities in batch
         $storageClient->updateEntity($tableName, $entities[0], true);
         $storageClient->updateEntity($tableName, $entities[1], true);
         $storageClient->updateEntity($tableName, $entities[2], true);
-
+        
         // Commit
         $exceptionThrown = false;
         try {
@@ -641,7 +668,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-
+    
     /**
      * Test batch commit, fail partition
      */
@@ -650,19 +677,20 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-
+        
         $entities = $this->_generateEntities(10);
-
+        
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-
+        
         // Insert entities in batch
-        foreach ($entities as $entity) {
+        foreach ($entities as $entity)
+        {
             $entity->setPartitionKey('partition' . rand(1, 9));
             $storageClient->insertEntity($tableName, $entity);
         }
-
+        
         // Commit
         $exceptionThrown = false;
         try {
@@ -671,31 +699,32 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
             $exceptionThrown = true;
         }
         $this->assertTrue($exceptionThrown);
-
+        
         // Verify
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(0, count($result));
     }
-
+    
     /**
      * Generate entities
-     *
+     * 
      * @param int 		$amount Number of entities to generate
      * @return array 			Array of TSTest_TestEntity
      */
     protected function _generateEntities($amount = 1)
     {
         $returnValue = array();
-
-        for ($i = 0; $i < $amount; $i++) {
+        
+        for ($i = 0; $i < $amount; $i++)
+        {
             $entity = new TSTest_TestEntity('partition1', 'row' . ($i + 1));
             $entity->FullName = md5(uniqid(rand(), true));
             $entity->Age      = rand(1, 130);
             $entity->Visible  = rand(1,2) == 1;
-
+            
             $returnValue[] = $entity;
         }
-
+        
         return $returnValue;
     }
 }
@@ -709,19 +738,14 @@ class TSTest_TestEntity extends Zend_Service_WindowsAzure_Storage_TableEntity
      * @azure Name
      */
     public $FullName;
-
+    
     /**
      * @azure Age Edm.Int64
      */
     public $Age;
-
+    
     /**
      * @azure Visible Edm.Boolean
      */
     public $Visible = false;
 }
-
-// Call Zend_Service_WindowsAzure_TableStorageTest::main() if this source file is executed directly.
-if (PHPUnit_MAIN_METHOD == "Zend_Service_WindowsAzure_TableStorageTest::main") {
-    Zend_Service_WindowsAzure_TableStorageTest::main();
-}
