@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Soap
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ClientTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version    $Id: ClientTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -41,7 +41,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Soap
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Soap
  */
@@ -202,6 +202,27 @@ class Zend_Soap_ClientTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('agent4', $options['user_agent']);
     }
 
+    /**
+     * @group ZF-6954
+     */
+    public function testUserAgentAllowsEmptyString()
+    {
+        $client = new Zend_Soap_Client();
+        $this->assertNull($client->getUserAgent());
+        $options = $client->getOptions();
+        $this->assertArrayNotHasKey('user_agent', $options);
+
+        $client->setUserAgent('');
+        $this->assertEquals('', $client->getUserAgent());
+        $options = $client->getOptions();
+        $this->assertEquals('', $options['user_agent']);
+
+        $client->setUserAgent(null);
+        $this->assertNull($client->getUserAgent());
+        $options = $client->getOptions();
+        $this->assertArrayNotHasKey('user_agent', $options);
+    }
+
     public function testGetFunctions()
     {
         $server = new Zend_Soap_Server(dirname(__FILE__) . '/_files/wsdl_example.wsdl');
