@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IsCompressedTest.php 20444 2010-01-20 16:04:13Z ralph $
+ * @version    $Id: IsCompressedTest.php 22686 2010-07-26 17:45:12Z ramon $
  */
 
 // Call Zend_Validate_File_MimeTypeTest::main() if this source file is executed directly.
@@ -73,7 +73,7 @@ class Zend_Validate_File_IsCompressedTest extends PHPUnit_Framework_TestCase
                 . ' but mime_content_type exhibits buggy behavior on this system.'
                 );
         }
-        
+
         $valuesExpected = array(
             array(null, true),
             array('zip', true),
@@ -188,13 +188,18 @@ class Zend_Validate_File_IsCompressedTest extends PHPUnit_Framework_TestCase
 
     public function testOptionsAtConstructor()
     {
+        if (!extension_loaded('fileinfo')) {
+            $this->markTestSkipped('This PHP Version has no finfo installed');
+        }
+
+        $magicFile = dirname(__FILE__) . '/_files/magic.mime';
         $validator = new Zend_Validate_File_IsCompressed(array(
             'image/gif',
             'image/jpg',
-            'magicfile' => __FILE__,
+            'magicfile'   => $magicFile,
             'headerCheck' => true));
 
-        $this->assertEquals(__FILE__, $validator->getMagicFile());
+        $this->assertEquals($magicFile, $validator->getMagicFile());
         $this->assertTrue($validator->getHeaderCheck());
         $this->assertEquals('image/gif,image/jpg', $validator->getMimeType());
     }
