@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IsImageTest.php 20337 2010-01-16 15:37:35Z thomas $
+ * @version    $Id: IsImageTest.php 22693 2010-07-26 19:31:40Z alexander $
  */
 
 // Call Zend_Validate_File_IsImageTest::main() if this source file is executed directly.
@@ -179,13 +179,17 @@ class Zend_Validate_File_IsImageTest extends PHPUnit_Framework_TestCase
 
     public function testOptionsAtConstructor()
     {
+        if (!extension_loaded('fileinfo')) {
+            $this->markTestSkipped('This PHP Version has no finfo installed');
+        }
+
         $validator = new Zend_Validate_File_IsImage(array(
             'image/gif',
             'image/jpg',
-            'magicfile' => __FILE__,
+            'magicfile' => dirname(__FILE__) . '/_files/magic.mime',
             'headerCheck' => true));
 
-        $this->assertEquals(__FILE__, $validator->getMagicFile());
+        $this->assertEquals(dirname(__FILE__) . '/_files/magic.mime', $validator->getMagicFile());
         $this->assertTrue($validator->getHeaderCheck());
         $this->assertEquals('image/gif,image/jpg', $validator->getMimeType());
     }
