@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MimeTypeTest.php 21472 2010-03-11 22:16:55Z thomas $
+ * @version    $Id: MimeTypeTest.php 22679 2010-07-26 13:02:33Z alexander $
  */
 
 // Call Zend_Validate_File_MimeTypeTest::main() if this source file is executed directly.
@@ -184,6 +184,7 @@ class Zend_Validate_File_MimeTypeTest extends PHPUnit_Framework_TestCase
         require_once 'Zend/Validate/Exception.php';
         try {
             $validator = new Zend_Validate_File_MimeType(array('image/gif', 'magicfile' => __FILE__));
+            $this->fail('Zend_Validate_File_MimeType should not accept invalid magic file.');
         } catch (Zend_Validate_Exception $e) {
             // @ZF-9320: False Magic File is not allowed to be set
         }
@@ -199,6 +200,47 @@ class Zend_Validate_File_MimeTypeTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($validator->getHeaderCheck());
         $this->assertEquals('image/gif,image/jpg', $validator->getMimeType());
     }
+
+    /**
+     * @group ZF-9686
+     */
+    public function testDualValidation()
+    {
+        $valuesExpected = array(
+            array('image', true),
+        );
+
+        $filetest = dirname(__FILE__) . '/_files/picture.jpg';
+        $files = array(
+            'name'     => 'picture.jpg',
+            'type'     => 'image/jpg',
+            'size'     => 200,
+            'tmp_name' => $filetest,
+            'error'    => 0
+        );
+
+        foreach ($valuesExpected as $element) {
+            $options   = array_shift($element);
+            $expected  = array_shift($element);
+            $validator = new Zend_Validate_File_MimeType($options);
+            $validator->enableHeaderCheck();
+            $this->assertEquals(
+                $expected,
+                $validator->isValid($filetest, $files),
+                "Test expected " . var_export($expected, 1) . " with " . var_export($options, 1)
+                . "\nMessages: " . var_export($validator->getMessages(), 1)
+            );
+
+            $validator = new Zend_Validate_File_MimeType($options);
+            $validator->enableHeaderCheck();
+            $this->assertEquals(
+                $expected,
+                $validator->isValid($filetest, $files),
+                "Test expected " . var_export($expected, 1) . " with " . var_export($options, 1)
+                . "\nMessages: " . var_export($validator->getMessages(), 1)
+            );
+        }
+    }
 }
 
 // Call Zend_Validate_File_MimeTypeTest::main() if this source file is executed directly.
