@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FloatTest.php 21664 2010-03-27 21:39:38Z thomas $
+ * @version    $Id: FloatTest.php 22296 2010-05-25 20:05:42Z thomas $
  */
 
 /**
@@ -167,13 +167,57 @@ class Zend_Validate_FloatTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($valid->isValid(10.5));
     }
 
+    /**
+     * @ZF-7987
+     */
+    public function testPhpLocaleFrFloatType()
+    {
+        setlocale(LC_ALL, 'fr');
+        $valid = new Zend_Validate_Float();
+        $this->assertTrue($valid->isValid(10.5));
+    }
+
     /**
      * @ZF-8919
      */
     public function testPhpLocaleDeStringType()
     {
+        setlocale(LC_ALL, 'de_AT');
         setlocale(LC_NUMERIC, 'de_AT');
-        $valid = new Zend_Validate_Float();
+        $valid = new Zend_Validate_Float('de_AT');
         $this->assertTrue($valid->isValid('1,3'));
+        $this->assertTrue($valid->isValid('1000,3'));
+        $this->assertTrue($valid->isValid('1.000,3'));
+        $this->assertFalse($valid->isValid('1.3'));
+        $this->assertFalse($valid->isValid('1000.3'));
+        $this->assertFalse($valid->isValid('1,000.3'));
+    }
+
+    /**
+     * @ZF-8919
+     */
+    public function testPhpLocaleFrStringType()
+    {
+        $valid = new Zend_Validate_Float('fr_FR');
+        $this->assertTrue($valid->isValid('1,3'));
+        $this->assertTrue($valid->isValid('1000,3'));
+        $this->assertTrue($valid->isValid('1 000,3'));
+        $this->assertFalse($valid->isValid('1.3'));
+        $this->assertFalse($valid->isValid('1000.3'));
+        $this->assertFalse($valid->isValid('1,000.3'));
+    }
+
+    /**
+     * @ZF-8919
+     */
+    public function testPhpLocaleEnStringType()
+    {
+        $valid = new Zend_Validate_Float('en_US');
+        $this->assertTrue($valid->isValid('1.3'));
+        $this->assertTrue($valid->isValid('1000.3'));
+        $this->assertTrue($valid->isValid('1,000.3'));
+        $this->assertFalse($valid->isValid('1,3'));
+        $this->assertFalse($valid->isValid('1000,3'));
+        $this->assertFalse($valid->isValid('1.000,3'));
     }
 }
