@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_XmlRpc
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version $Id: FaultTest.php 18951 2009-11-12 16:26:19Z alexander $
+ * @version $Id: FaultTest.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 // Call Zend_XmlRpc_Server_FaultTest::main() if this source file is executed directly.
@@ -38,7 +38,7 @@ require_once 'Zend/XmlRpc/Server/Fault.php';
  * @category   Zend
  * @package    Zend_XmlRpc
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_XmlRpc
  */
@@ -243,13 +243,12 @@ class Zend_XmlRpc_Server_FaultTest extends PHPUnit_Framework_TestCase
 
         $xml = $dom->saveXML();
 
+        require_once 'Zend/XmlRpc/Server/Exception.php';
         $e = new Zend_XmlRpc_Server_Exception('Testing fault', 411);
         $fault = Zend_XmlRpc_Server_Fault::getInstance($e);
 
-        $this->assertEquals($xml, $fault->__toString());
+        $this->assertEquals(trim($xml), trim($fault->__toString()));
     }
-
-
 }
 
 class zxrs_fault_test_exception extends Exception {}
